@@ -1,6 +1,6 @@
 /* gpgv.c - The GnuPG signature verify utility
- * Copyright (C) 1998, 1999, 2000, 2001, 2002, 2005,
- *               2006, 2008 Free Software Foundation, Inc.
+ * Copyright (C) 1998, 1999, 2000, 2001, 2002, 2005, 2006,
+ *               2008, 2009, 2012 Free Software Foundation, Inc.
  *
  * This file is part of GnuPG.
  *
@@ -232,7 +232,8 @@ check_signatures_trust( PKT_signature *sig )
 
 void
 read_trust_options(byte *trust_model, ulong *created, ulong *nextcheck,
-		   byte *marginals, byte *completes, byte *cert_depth) 
+		   byte *marginals, byte *completes, byte *cert_depth,
+		   byte *min_cert_level)
 {
   (void)trust_model;
   (void)created;
@@ -240,6 +241,7 @@ read_trust_options(byte *trust_model, ulong *created, ulong *nextcheck,
   (void)marginals;
   (void)completes;
   (void)cert_depth;
+  (void)min_cert_level;
 }
 
 /* Stub: 
